Snippet pyproject.toml
=======================

.. automodule:: drain_swamp.snippet_pyproject_toml
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: Manipulate pyproject.toml snippet contents
